aboutsummaryrefslogtreecommitdiff
path: root/engines/tinsel/sound.cpp
diff options
context:
space:
mode:
authorMax Horn2011-04-14 14:34:28 +0200
committerMax Horn2011-04-14 14:34:28 +0200
commit2e095e25f2435f0d066d2826176e394bda5c4a9c (patch)
tree81d2c4d9e26e4a7644087a13c61b785ae3e431c8 /engines/tinsel/sound.cpp
parent84184aabc00251374a181fe296487619afa779ed (diff)
downloadscummvm-rg350-2e095e25f2435f0d066d2826176e394bda5c4a9c.tar.gz
scummvm-rg350-2e095e25f2435f0d066d2826176e394bda5c4a9c.tar.bz2
scummvm-rg350-2e095e25f2435f0d066d2826176e394bda5c4a9c.zip
ALL: centre -> center
Diffstat (limited to 'engines/tinsel/sound.cpp')
-rw-r--r--engines/tinsel/sound.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/engines/tinsel/sound.cpp b/engines/tinsel/sound.cpp
index 1fcdb4dcf9..9a08b6224b 100644
--- a/engines/tinsel/sound.cpp
+++ b/engines/tinsel/sound.cpp
@@ -364,8 +364,8 @@ bool SoundManager::offscreenChecks(int x, int &y) {
if (x == -1)
return true;
- // convert x to offset from screen centre
- x -= PlayfieldGetCentreX(FIELD_WORLD);
+ // convert x to offset from screen center
+ x -= PlayfieldGetCenterX(FIELD_WORLD);
if (x < -SCREEN_WIDTH || x > SCREEN_WIDTH) {
// A long way offscreen, ignore it
@@ -385,7 +385,7 @@ int8 SoundManager::getPan(int x) {
if (x == -1)
return 0;
- x -= PlayfieldGetCentreX(FIELD_WORLD);
+ x -= PlayfieldGetCenterX(FIELD_WORLD);
if (x == 0)
return 0;